spacepy.toolbox.query_yes_no — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.query_yes_no

`spacepy.toolbox.` `query_yes_no`(question, default='yes')

  Ask a yes/no question via raw_input() and return their answer.

  “question” is a string that is presented to the user. “default” is the presumed answer if the user just hits <Enter>. It must be “yes” (the default), “no” or None (meaning an answer is required of the user).

  The “answer” return value is one of “yes” or “no”.

  Parameters: | question : string the question to ask default : string (optional)
  Returns: | out : string answer (‘yes’ or ‘no’)

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.query_yes_no('Ready to go?')
      Ready to go? [Y/n] y
      'yes'

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »